@@ -27,7 +27,7 @@ else:
 	from defaultpaths import (xdg_config_dir_default, xdg_config_home, 
 							  xdg_data_home, xdg_data_home_default, 
 							  xdg_data_dirs)
-from defaultpaths import (autostart, autostart_home, iccprofiles,
+from defaultpaths import (autostart, autostart_home, home, iccprofiles,
 						  iccprofiles_home)
 from meta import name as appname, build, lastmod, version
 from options import ascii, debug, verbose
@@ -154,6 +154,7 @@ resfiles = [
 	"ref/ClayRGB1998.gam",
 	"ref/sRGB.gam",
 	"ref/verify_extended.ti1",
+	"ti1/d3-e4-s2-g25-m0-b0-f0.ti1",
 	"ti1/d3-e4-s0-g25-m3-b3-f0-crossover.ti1",
 	"ti1/d3-e4-s0-g49-m3-b3-f0-crossover.ti1",
 	"ti1/d3-e4-s13-g37-m4-b4-f0.ti1",
@@ -465,6 +466,12 @@ def get_icon_bundle(sizes, name):
 	""" Return a wx.IconBundle with given icon sizes """
 	from wxaddons import wx
 	iconbundle = wx.IconBundle()
+	if not sizes:
+		# Assume ICO format
+		ico = get_data_path("theme/icons/%s.ico" % name)
+		if ico:
+			iconbundle.AddIconFromFile(ico, wx.BITMAP_TYPE_ICO)
+			return iconbundle
 	for size in sizes:
 		iconbundle.AddIcon(get_bitmap_as_icon(size, name, False))
 	return iconbundle
@@ -652,6 +659,10 @@ valid_ranges = {
 	"tc_vrml_black_offset": [0, 40],
 	"webserver.portnumber": [1, 65535],
 	"whitepoint.colortemp": [1000, 15000],
+	"whitepoint.visual_editor.bg_v": [0, 255],
+	"whitepoint.visual_editor.b": [0, 255],
+	"whitepoint.visual_editor.g": [0, 255],
+	"whitepoint.visual_editor.r": [0, 255],
 }
 
 valid_values = {
@@ -667,7 +678,7 @@ valid_values = {
 	"3dlut.image.layout": ["h", "v"],
 	"3dlut.image.order": ["rgb", "bgr"],
 	"3dlut.rendering_intent": intents,
-	"3dlut.size": [16, 17, 24, 32, 33, 64, 65],
+	"3dlut.size": [5, 9, 16, 17, 24, 32, 33, 64, 65],
 	"3dlut.trc": ["bt1886", "customgamma", "gamma2.2", "smpte2084.hardclip", "smpte2084.rolloffclip"],
 	"3dlut.trc_gamma_type": ["b", "B"],
 	"calibration.quality": ["v", "l", "m", "h", "u"],
@@ -707,7 +718,7 @@ valid_values = {
 	"tc_vrml_cie_colorspace": ["DIN99", "DIN99b", "DIN99c", "DIN99d", "ICtCp",
 							   "LCH(ab)", "LCH(uv)", "Lab", "Luv", "Lu'v'", "xyY"],
 	"tc_vrml_device_colorspace": ["HSI", "HSL", "HSV", "RGB"],
-	"testchart.auto_optimize": [0, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18],
+	"testchart.auto_optimize": [0, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18],
 	"trc": ["240", "709", "l", "s", ""],
 	"trc.type": ["g", "G"],
 	"uniformity.cols": [3, 5, 7, 9],
@@ -812,6 +823,7 @@ defaults = {
 																	  version),
 	"dimensions.measureframe": "0.5,0.5,1.5",
 	"dimensions.measureframe.unzoomed": "0.5,0.5,1.5",
+	"dimensions.measureframe.whitepoint.visual_editor": "0.5,0.5,1.5",
 	"display.number": 1,
 	"display_lut.link": 1,
 	"display_lut.number": 1,
@@ -940,9 +952,11 @@ defaults = {
 	"profile.save_path": storage, # directory
 	"profile.type": "X",
 	"profile.update": 0,
+	"profile_loader.buggy_video_drivers":  ";".join(["intel"]),
 	"profile_loader.check_gamma_ramps": 0,
 	"profile_loader.error.show_msg": 1,
-	"profile_loader.fix_profile_associations": 0,
+	"profile_loader.exceptions": "",
+	"profile_loader.fix_profile_associations": 1,
 	"profile_loader.known_apps": ";".join(["basiccolor display.exe",
 										   "calclient.exe",
 										   "coloreyes display pro.exe",
@@ -954,6 +968,7 @@ defaults = {
 										   "hp_dreamcolor_calibration_solution.exe",
 										   "i1profiler.exe",
 										   "icolordisplay.exe",
+										   "spectraview.exe",
 										   "spectraview profiler.exe",
 										   "spyder3elite.exe",
 										   "spyder3express.exe",
@@ -1038,7 +1053,6 @@ defaults = {
 	"tc_white_patches": 4,
 	"tc.show": 0,
 	"testchart.auto_optimize": 5,
-	"testchart.auto_optimize.fix_zero_blackpoint": 0,
 	"testchart.file": "auto",
 	"testchart.file.backup": "auto",
 	"testchart.reference": "",
@@ -1064,6 +1078,10 @@ defaults = {
 	"whitepoint.colortemp": 5000,
 	"whitepoint.colortemp.backup": 5000,
 	"whitepoint.colortemp.locus": "t",
+	"whitepoint.visual_editor.bg_v": 255,
+	"whitepoint.visual_editor.b": 255,
+	"whitepoint.visual_editor.g": 255,
+	"whitepoint.visual_editor.r": 255,
 	"whitepoint.x": 0.345741,
 	"whitepoint.x.backup": 0.345741,
 	"whitepoint.y": 0.358666,
@@ -1494,7 +1512,10 @@ def initcfg(module=None):
 		setcfg("calibration.file", defaults["calibration.file"])
 	# Read cfg
 	cfgnames = []
-	if module != "3DLUT-maker":
+	if module not in ("3DLUT-maker", "VRML-to-X3D-converter",
+					  "scripting-client"):
+		# Never read base app cfg for 3D LUT maker, VRML converter and
+		# scripting client
 		cfgnames.append(appbasename)
 	if module:
 		cfgnames.append(cfgbasename)
@@ -1512,7 +1533,10 @@ def initcfg(module=None):
 				cfgfiles.append(cfgfile)
 				# Make user config take precedence
 				break
-	cfgfiles.sort(key=lambda cfgfile: os.stat(cfgfile).st_mtime)
+	if len(cfgfiles) > 1 and (module != "apply-profiles" or
+							  sys.platform != "win32"):
+		# Make most recent file take precedence
+		cfgfiles.sort(key=lambda cfgfile: os.stat(cfgfile).st_mtime)
 	try:
 		cfg.read(cfgfiles)
 		# This won't raise an exception if the file does not exist, only
